summaryrefslogtreecommitdiffstats
path: root/src/usr/fapi2/test/fapi2GetChildrenTest.H
diff options
context:
space:
mode:
authorMarty Gloff <mgloff@us.ibm.com>2016-02-01 09:07:03 -0600
committerMatthew A. Ploetz <maploetz@us.ibm.com>2016-04-27 06:40:46 -0400
commit76febbb5c230f1231be719831f84923fb802cb95 (patch)
tree54b45deb80a2a091db0c44daa19751e191e70afc /src/usr/fapi2/test/fapi2GetChildrenTest.H
parent5e80adfa475e07dcd896de7ced5004cf51e95ff5 (diff)
downloadtalos-hostboot-76febbb5c230f1231be719831f84923fb802cb95.tar.gz
talos-hostboot-76febbb5c230f1231be719831f84923fb802cb95.zip
P9 changes for PR core restriction
Covers the work required to support the P9 module vpd and new EQ/EX/EC core structure in relation to the processing of the PR keyword to restrict the number of cores. Add new traces or enhance old traces with additional data to improve debug. Update the module vpd binary for our standalone model. Change-Id: I20018ccf1daa429e5b0ad9e38f50b1bc5943bcb5 RTC:145459 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/705 Tested-by: Jenkins Server Tested-by: FSP CI Jenkins Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Matthew A. Ploetz <maploetz@us.ibm.com>
Diffstat (limited to 'src/usr/fapi2/test/fapi2GetChildrenTest.H')
-rw-r--r--src/usr/fapi2/test/fapi2GetChildrenTest.H16
1 files changed, 12 insertions, 4 deletions
diff --git a/src/usr/fapi2/test/fapi2GetChildrenTest.H b/src/usr/fapi2/test/fapi2GetChildrenTest.H
index 855028cb5..ddcf1f9ae 100644
--- a/src/usr/fapi2/test/fapi2GetChildrenTest.H
+++ b/src/usr/fapi2/test/fapi2GetChildrenTest.H
@@ -142,10 +142,11 @@ void test_fapi2GetChildren()
// l_actualSize = l_childMCAs.size();
//
// //Set expected size to be the number of MCAs per MCBIST
-// l_expectedSize = 2;
+// l_expectedSize = MCA_PER_MCS * MCS_PER_PROC / MCBIST_PER_PROC;
// numTests++;
// if(l_actualSize != l_expectedSize)
// {
+// FAPI_INF("fapi2TargetTest:: MCAs per MCBIST mismatch");
// numFails++;
// break;
// }
@@ -159,6 +160,7 @@ void test_fapi2GetChildren()
numTests++;
if(l_actualSize != l_expectedSize)
{
+ FAPI_INF("fapi2TargetTest:: present cores per proc mismatch");
numFails++;
break;
}
@@ -168,10 +170,11 @@ void test_fapi2GetChildren()
l_actualSize = l_childCores.size();
//Set expected size to be the number of cores per proc
- l_expectedSize = 1;
+ l_expectedSize = EQ_PER_PROC * EX_PER_EQ * CORE_PER_EX;
numTests++;
if(l_actualSize != l_expectedSize)
{
+ FAPI_INF("fapi2TargetTest:: functional cores per proc mismatch");
numFails++;
break;
}
@@ -180,11 +183,12 @@ void test_fapi2GetChildren()
l_targetHuid = TARGETING::get_huid(l_nimbusProc) ;
l_actualSize = l_childMCAs.size();
- //Set expected size to be the number of cores per proc
- l_expectedSize = 8;
+ //Set expected size to be the number of MCAs per proc
+ l_expectedSize = MCA_PER_MCS * MCS_PER_PROC;
numTests++;
if(l_actualSize != l_expectedSize)
{
+ FAPI_INF("fapi2TargetTest:: MCAs per proc mismatch");
numFails++;
break;
}
@@ -198,6 +202,7 @@ void test_fapi2GetChildren()
numTests++;
if(l_actualSize != l_expectedSize)
{
+ FAPI_INF("fapi2TargetTest:: cores per EX mismatch");
numFails++;
break;
}
@@ -211,6 +216,7 @@ void test_fapi2GetChildren()
numTests++;
if(l_actualSize != l_expectedSize)
{
+ FAPI_INF("fapi2TargetTest:: cores per EQ mismatch");
numFails++;
break;
}
@@ -379,6 +385,7 @@ void test_fapi2GetChildren()
if(candidateTarget == NULL)
{
+ FAPI_INF("fapi2TargetTest:: candidateTarget not found");
numFails++;
break;
}
@@ -392,6 +399,7 @@ void test_fapi2GetChildren()
if(l_actualSize != l_expectedSize)
{
+ FAPI_INF("fapi2TargetTest:: children of pervasive mismatch");
numFails++;
break;
}
OpenPOWER on IntegriCloud